@@ -6,10 +6,18 @@ function(X,y,P=NULL,lambda=1,ncomp=NULL,k=5,kernel=FALSE,scale=FALSE){
   if (is.null(ncomp)) ncomp=min(n-1,ncol(X))
   
   lambda=as.vector(lambda)
-  if (is.null(P)==TRUE) P=matrix(0,ncol(X),ncol(X))
-  error.cv=matrix(0,length(lambda),ncomp)
+  if (is.null(P)==TRUE) {lambda=0}
+ 
   all.folds <- split(sample(1:n), rep(1:k,length=n))
-  
+  # ensure that ncomp does not exceed the sample size on the cv splits
+  ntrain=vector(length=k)
+  for (i in 1:k){
+    ntrain[i]=n- length(all.folds[[i]])
+  }
+  ntrain.min=min(ntrain)
+  ncomp=min(ncomp,ntrain.min-1)
+   error.cv=matrix(0,length(lambda),ncomp)
+  #
   for (i in seq(k)) {
         omit <- all.folds[[i]]
         Xtrain=X[-omit,,drop=FALSE]
@@ -17,12 +25,12 @@ function(X,y,P=NULL,lambda=1,ncomp=NULL,k=5,kernel=FALSE,scale=FALSE){
         Xtest=X[omit,,drop=FALSE]
         ytest=y[omit]
         for (j in 1:length(lambda)){
-		if (is.null(P)==TRUE){
-			Pj=NULL
-		}
-		if (is.null(P)==FALSE){
-			Pj=lambda[j]*P
-		}
+        if (is.null(P)==TRUE){
+            Pj=NULL
+        }
+        if (is.null(P)==FALSE){
+            Pj=lambda[j]*P
+        }
             penpls=penalized.pls(Xtrain,ytrain,P=Pj,ncomp,kernel=kernel,scale=scale)
             error.cv[j,]=error.cv[j,]+ length(ytest)*(new.penalized.pls(penpls,Xtest,ytest)$mse)
         }
@@ -34,12 +42,12 @@ function(X,y,P=NULL,lambda=1,ncomp=NULL,k=5,kernel=FALSE,scale=FALSE){
   lambda.opt=lambda[which.min(value1)]
   ncomp.opt=which.min(error.cv[lambda==lambda.opt,])
   min.ppls=min(value1)
-	if (is.null(P)==TRUE){
-			P.opt=NULL
-		}
-		if (is.null(P)==FALSE){
-			P.opt=lambda.opt*P
-		}
+    if (is.null(P)==TRUE){
+            P.opt=NULL
+        }
+        if (is.null(P)==FALSE){
+            P.opt=lambda.opt*P
+        }
   ppls=penalized.pls(X,y,P.opt,ncomp=ncomp.opt,kernel)
   intercept=ppls$intercept[ncomp.opt]
   coefficients=ppls$coefficients[,ncomp.opt]
